@@ -1,9 +1,9 @@
 /*
- * "$Id: cups.h 11978 2014-07-02 10:35:09Z msweet $"
+ * "$Id: cups.h 13031 2016-01-04 14:43:04Z msweet $"
  *
  * API definitions for CUPS.
  *
- * Copyright 2007-2014 by Apple Inc.
+ * Copyright 2007-2016 by Apple Inc.
  * Copyright 1997-2007 by Easy Software Products.
  *
  * These coded instructions, statements, and computer programs are the
@@ -35,6 +35,15 @@ typedef off_t ssize_t;			/* @private@ */
 #  include "language.h"
 #  include "pwg.h"
 
+/*
+ * Define _PPD_DEPRECATED to silence the warnings about PPD functions being
+ * deprecated...
+ */
+
+#  ifndef _PPD_DEPRECATED
+#    define _PPD_DEPRECATED _CUPS_DEPRECATED_1_6_MSG("Use cupsCopyDestInfo and friends instead.")
+#  endif /* !_PPD_DEPRECATED */
+
 
 /*
  * C++ magic...
@@ -49,10 +58,10 @@ extern "C" {
  * Constants...
  */
 
-#  define CUPS_VERSION			1.0704
-#  define CUPS_VERSION_MAJOR		1
-#  define CUPS_VERSION_MINOR		7
-#  define CUPS_VERSION_PATCH		4
+#  define CUPS_VERSION			2.0103
+#  define CUPS_VERSION_MAJOR		2
+#  define CUPS_VERSION_MINOR		1
+#  define CUPS_VERSION_PATCH		3
 
 #  define CUPS_BC_FD			3
 					/* Back-channel file descriptor for
@@ -241,6 +250,7 @@ enum cups_ptype_e			/* Printer type/capability bit
 					 * @since CUPS 1.4/OS X 10.6@ */
   CUPS_PRINTER_MFP = 0x4000000,		/* Printer with scanning capabilities
 					 * @since CUPS 1.4/OS X 10.6@ */
+  CUPS_PRINTER_3D = 0x8000000,		/* 3D Printing @since CUPS 2.1@ */
   CUPS_PRINTER_OPTIONS = 0x6fffc	/* ~(CLASS | REMOTE | IMPLICIT |
 					 * DEFAULT | FAX | REJECTING | DELETE |
 					 * NOT_SHARED | AUTHENTICATED |
@@ -354,8 +364,7 @@ extern int		cupsGetClasses(char ***classes) _CUPS_DEPRECATED_MSG("Use cupsGetDes
 extern const char	*cupsGetDefault(void);
 extern int		cupsGetJobs(cups_job_t **jobs, const char *name,
 			            int myjobs, int whichjobs);
-extern const char	*cupsGetPPD(const char *name)
-			            _CUPS_DEPRECATED_1_6_MSG("Use cupsCopyDestInfo instead.");
+extern const char	*cupsGetPPD(const char *name) _PPD_DEPRECATED;
 extern int		cupsGetPrinters(char ***printers) _CUPS_DEPRECATED_MSG("Use cupsGetDests instead.");
 extern ipp_status_t	cupsLastError(void);
 extern int		cupsPrintFile(const char *name, const char *filename,
@@ -413,8 +422,7 @@ extern int		cupsGetDests2(http_t *http, cups_dest_t **dests)
 extern int		cupsGetJobs2(http_t *http, cups_job_t **jobs,
 			             const char *name, int myjobs,
 				     int whichjobs) _CUPS_API_1_1_21;
-extern const char	*cupsGetPPD2(http_t *http, const char *name)
-			             _CUPS_DEPRECATED_1_6_MSG("Use cupsCopyDestInfo instead.");
+extern const char	*cupsGetPPD2(http_t *http, const char *name) _PPD_DEPRECATED;
 extern int		cupsPrintFile2(http_t *http, const char *name,
 			               const char *filename,
 				       const char *title, int num_options,
@@ -479,7 +487,7 @@ extern const char	*cupsGetPassword2(const char *prompt, http_t *http,
 					  const char *resource) _CUPS_API_1_4;
 extern http_status_t	cupsGetPPD3(http_t *http, const char *name,
 			            time_t *modtime, char *buffer,
-				    size_t bufsize) _CUPS_API_1_4;
+				    size_t bufsize) _PPD_DEPRECATED;
 extern ipp_t		*cupsGetResponse(http_t *http,
 			                 const char *resource) _CUPS_API_1_4;
 extern ssize_t		cupsReadResponseData(http_t *http, char *buffer,
@@ -615,6 +623,11 @@ extern int		cupsGetDestMediaDefault(http_t *http, cups_dest_t *dest,
 extern void		cupsSetUserAgent(const char *user_agent) _CUPS_API_1_7;
 extern const char	*cupsUserAgent(void) _CUPS_API_1_7;
 
+/* New in CUPS 2.0/OS X 10.10 */
+extern cups_dest_t	*cupsGetDestWithURI(const char *name, const char *uri) _CUPS_API_2_0;
+extern const char	*cupsLocalizeDestMedia(http_t *http, cups_dest_t *dest, cups_dinfo_t *info, unsigned flags, cups_size_t *size) _CUPS_API_2_0;
+extern int		cupsMakeServerCredentials(const char *path, const char *common_name, int num_alt_names, const char **alt_names, time_t expiration_date) _CUPS_API_2_0;
+extern int		cupsSetServerCredentials(const char *path, const char *common_name, int auto_create) _CUPS_API_2_0;
 
 #  ifdef __cplusplus
 }
@@ -623,5 +636,5 @@ extern const char	*cupsUserAgent(void) _CUPS_API_1_7;
 #endif /* !_CUPS_CUPS_H_ */
 
 /*
- * End of "$Id: cups.h 11978 2014-07-02 10:35:09Z msweet $".
+ * End of "$Id: cups.h 13031 2016-01-04 14:43:04Z msweet $".
  */
